# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKIOJPEGPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkJPEGImageIOPython
else:
    import _itkJPEGImageIOPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKIOImageBaseBasePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython

def itkJPEGImageIO_New():
    return itkJPEGImageIO.New()

class itkJPEGImageIO(itk.ITKIOImageBaseBasePython.itkImageIOBase):
    r"""Proxy of C++ itkJPEGImageIO class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkJPEGImageIO_Pointer"""
        return _itkJPEGImageIOPython.itkJPEGImageIO___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkJPEGImageIO_Pointer"""
        return _itkJPEGImageIOPython.itkJPEGImageIO_Clone(self)

    def SetQuality(self, _JPEGQuality):
        r"""
        SetQuality(self, _JPEGQuality)

        Parameters
        ----------
        _JPEGQuality: int

        """
        return _itkJPEGImageIOPython.itkJPEGImageIO_SetQuality(self, _JPEGQuality)

    def GetQuality(self):
        r"""GetQuality(self) -> int"""
        return _itkJPEGImageIOPython.itkJPEGImageIO_GetQuality(self)

    def SetProgressive(self, _arg):
        r"""
        SetProgressive(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkJPEGImageIOPython.itkJPEGImageIO_SetProgressive(self, _arg)

    def GetProgressive(self):
        r"""GetProgressive(self) -> bool"""
        return _itkJPEGImageIOPython.itkJPEGImageIO_GetProgressive(self)

    def ProgressiveOn(self):
        r"""ProgressiveOn(self)"""
        return _itkJPEGImageIOPython.itkJPEGImageIO_ProgressiveOn(self)

    def ProgressiveOff(self):
        r"""ProgressiveOff(self)"""
        return _itkJPEGImageIOPython.itkJPEGImageIO_ProgressiveOff(self)

    def SetCMYKtoRGB(self, _arg):
        r"""
        SetCMYKtoRGB(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkJPEGImageIOPython.itkJPEGImageIO_SetCMYKtoRGB(self, _arg)

    def GetCMYKtoRGB(self):
        r"""GetCMYKtoRGB(self) -> bool"""
        return _itkJPEGImageIOPython.itkJPEGImageIO_GetCMYKtoRGB(self)

    def CMYKtoRGBOn(self):
        r"""CMYKtoRGBOn(self)"""
        return _itkJPEGImageIOPython.itkJPEGImageIO_CMYKtoRGBOn(self)

    def CMYKtoRGBOff(self):
        r"""CMYKtoRGBOff(self)"""
        return _itkJPEGImageIOPython.itkJPEGImageIO_CMYKtoRGBOff(self)

    def ReadVolume(self, buffer):
        r"""
        ReadVolume(self, buffer)

        Parameters
        ----------
        buffer: void *

        """
        return _itkJPEGImageIOPython.itkJPEGImageIO_ReadVolume(self, buffer)
    __swig_destroy__ = _itkJPEGImageIOPython.delete_itkJPEGImageIO

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkJPEGImageIO

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkJPEGImageIOPython.itkJPEGImageIO_cast(obj)

    def New(*args, **kargs):
        """New() -> itkJPEGImageIO

        Create a new object of the class itkJPEGImageIO and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkJPEGImageIO.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkJPEGImageIO.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkJPEGImageIO.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkJPEGImageIO in _itkJPEGImageIOPython:
_itkJPEGImageIOPython.itkJPEGImageIO_swigregister(itkJPEGImageIO)

def itkJPEGImageIOFactory_New():
    return itkJPEGImageIOFactory.New()

class itkJPEGImageIOFactory(itk.ITKCommonBasePython.itkObjectFactoryBase):
    r"""Proxy of C++ itkJPEGImageIOFactory class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkJPEGImageIOFactory_Pointer"""
        return _itkJPEGImageIOPython.itkJPEGImageIOFactory___New_orig__()

    @staticmethod
    def FactoryNew():
        r"""FactoryNew() -> itkJPEGImageIOFactory"""
        return _itkJPEGImageIOPython.itkJPEGImageIOFactory_FactoryNew()

    @staticmethod
    def RegisterOneFactory():
        r"""RegisterOneFactory()"""
        return _itkJPEGImageIOPython.itkJPEGImageIOFactory_RegisterOneFactory()
    __swig_destroy__ = _itkJPEGImageIOPython.delete_itkJPEGImageIOFactory

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkJPEGImageIOFactory

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkJPEGImageIOPython.itkJPEGImageIOFactory_cast(obj)

    def New(*args, **kargs):
        """New() -> itkJPEGImageIOFactory

        Create a new object of the class itkJPEGImageIOFactory and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkJPEGImageIOFactory.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkJPEGImageIOFactory.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkJPEGImageIOFactory.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkJPEGImageIOFactory in _itkJPEGImageIOPython:
_itkJPEGImageIOPython.itkJPEGImageIOFactory_swigregister(itkJPEGImageIOFactory)

